@@ -1,5 +1,4 @@
-/*  $Id: setproctitle.c 10063 2016-09-04 12:53:12Z iulius $
-**
+/*
 **  Replacement for a missing setproctitle.
 **
 **  Provides the same functionality as the BSD function setproctitle on hosts
@@ -12,16 +11,16 @@
 **  stubbed out on those platforms that don't need it.
 */
 
-#include "config.h"
-#include "clibrary.h"
+#include "portable/system.h"
+
 #include "portable/setproctitle.h"
 
 #include "inn/messages.h"
 
 #if HAVE_PSTAT
 
-#include <sys/param.h>
-#include <sys/pstat.h>
+#    include <sys/param.h>
+#    include <sys/pstat.h>
 
 void
 setproctitle(const char *format, ...)
@@ -35,7 +34,7 @@ setproctitle(const char *format, ...)
         delta = snprintf(title, sizeof(title), "%s: ", message_program_name);
         if (delta < 0)
             delta = 0;
-        else if ((size_t)delta >= sizeof(title))
+        else if ((size_t) delta >= sizeof(title))
             delta = sizeof(title);
     }
     va_start(args, format);
