@@ -88,7 +88,7 @@
  */
 
 #include "config.h"
-#include "clibrary.h"
+#include "portable/system.h"
 
 #include "inn/messages.h"
 #include "inn/xmalloc.h"
